@@ -51,26 +51,30 @@
 #'   \code{4} was matched to agent \code{6}.
 #' @examples
 #' # example using cardinal utilities
-#' utils = matrix(c(-1.4, -0.66, -0.45, 0.03,
-#'                  0.72, 1.71, 0.59, 0.07,
-#'                  0.44, 1.76, 1.71, -0.27,
-#'                  0.26, 2.18, 1.4, 0.12), byrow = TRUE, nrow = 4)
+#' utils <- matrix(c(
+#'   -1.4, -0.66, -0.45, 0.03,
+#'   0.72, 1.71, 0.59, 0.07,
+#'   0.44, 1.76, 1.71, -0.27,
+#'   0.26, 2.18, 1.4, 0.12
+#' ), byrow = TRUE, nrow = 4)
 #' utils
-#' results = toptrading(utils = utils)
+#' results <- toptrading(utils = utils)
 #' results
 #'
 #' # example using ordinal preferences
-#' pref = matrix(c(2, 4, 3, 4,
-#'                 3, 3, 4, 2,
-#'                 4, 2, 2, 1,
-#'                 1, 1, 1, 3), byrow = TRUE, nrow = 4)
+#' pref <- matrix(c(
+#'   2, 4, 3, 4,
+#'   3, 3, 4, 2,
+#'   4, 2, 2, 1,
+#'   1, 1, 1, 3
+#' ), byrow = TRUE, nrow = 4)
 #' pref
-#' results = toptrading(pref = pref)
+#' results <- toptrading(pref = pref)
 #' results
 #' @export
-toptrading = function(utils = NULL, pref = NULL) {
-    args = galeShapley.validate(proposerPref = pref, reviewerPref = pref, proposerUtils = utils, reviewerUtils = utils)
-    cpp_wrapper_ttc(args$proposerPref) + 1
+toptrading <- function(utils = NULL, pref = NULL) {
+  args <- galeShapley.validate(proposerPref = pref, reviewerPref = pref, proposerUtils = utils, reviewerUtils = utils)
+  cpp_wrapper_ttc(args$proposerPref) + 1
 }
 
 #' Check if there are any pairs of agents who would rather swap houses with
@@ -92,19 +96,23 @@ toptrading = function(utils = NULL, pref = NULL) {
 #'   then agent \code{4} was matched to agent \code{6}.
 #' @return true if the matching is stable, false otherwise
 #' @examples
-#' pref = matrix(c(2, 4, 3, 4,
-#'                 3, 3, 4, 2,
-#'                 4, 2, 2, 1,
-#'                 1, 1, 1, 3), byrow = TRUE, nrow = 4)
+#' pref <- matrix(c(
+#'   2, 4, 3, 4,
+#'   3, 3, 4, 2,
+#'   4, 2, 2, 1,
+#'   1, 1, 1, 3
+#' ), byrow = TRUE, nrow = 4)
 #' pref
-#' results = toptrading(pref = pref)
+#' results <- toptrading(pref = pref)
 #' results
 #' toptrading.checkStability(pref = pref, matchings = results)
 #' @export
-toptrading.checkStability = function(utils = NULL, pref = NULL, matchings) {
-    args = galeShapley.validate(proposerPref = pref,
-                                reviewerPref = pref,
-                                proposerUtils = utils,
-                                reviewerUtils = utils)
-    cpp_wrapper_ttc_check_stability(args$proposerPref, matchings - 1)
+toptrading.checkStability <- function(utils = NULL, pref = NULL, matchings) {
+  args <- galeShapley.validate(
+    proposerPref = pref,
+    reviewerPref = pref,
+    proposerUtils = utils,
+    reviewerUtils = utils
+  )
+  cpp_wrapper_ttc_check_stability(args$proposerPref, matchings - 1)
 }
