@@ -157,7 +157,7 @@ test_that("Check outcome from student-optimal galeShapley.collegeAdmissions matc
   expect_true(all.equal(matching$matched.students, matrix(c(2, 1, 2), ncol = 1)))
 })
 
-test_that("Check outcome from collge-optimal galeShapley.collegeAdmissions matching", {
+test_that("Check outcome from college-optimal galeShapley.collegeAdmissions matching", {
   uM <- matrix(c(
     0, 1,
     1, 0,
@@ -234,7 +234,7 @@ test_that("Check if galeShapley.collegeAdmissions matching returns the same resu
   expect_true(identical(matching1, matching2))
 })
 
-test_that("Check student-optimal galeShapley.collegeAdmissions with differnet numbers of slots", {
+test_that("Check student-optimal galeShapley.collegeAdmissions with different numbers of slots", {
 
   # four students, two colleges, slots c(1,2)
   uStudents <- matrix(runif(8), nrow = 2, ncol = 4)
@@ -257,7 +257,7 @@ test_that("Check student-optimal galeShapley.collegeAdmissions with differnet nu
   expect_equal(matching1$matched.students, matching2$proposals)
 })
 
-test_that("Check college-optimal galeShapley.collegeAdmissions with differnet numbers of slots", {
+test_that("Check college-optimal galeShapley.collegeAdmissions with different numbers of slots", {
 
   # four students, two colleges, slots c(1,2)
   uStudents <- matrix(runif(8), nrow = 2, ncol = 4)
